=====
PyDSE
=====

Toolset for Dynamic System Estimation for time series inspired by
`DSE <http://cran.r-project.org/web/packages/dse/index.html>`_.
It is in a beta state and only includes ARMA models right now.


Contents
========

.. toctree::
   :maxdepth: 2

   Create and Simulate <simulate>
   Estimation of Parameters <estimate>
   Forecast with Horizon <forecast>
   Contribution <contrib>
   License <license>
   Changelog <changes>
   Module Reference <_rst/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
